require('dotenv').config();
const express = require('express');
const { Sequelize } = require('sequelize');
const http = require('http');
const WebSocket = require('ws');

const app = express();
const server = http.createServer(app);
const wss = new WebSocket.Server({ server });

const sequelize = new Sequelize(process.env.DATABASE_URL, {
  dialect: 'postgres',
});

app.use(express.json());

const roomRoutes = require('./routes/rooms');
const playerRoutes = require('./routes/players');
const gameRoutes = require('./routes/game');

app.use('/api/rooms', roomRoutes);
app.use('/api/players', playerRoutes);
app.use('/api/game', gameRoutes);

sequelize.sync().then(() => {
  console.log('Database synced');
});

wss.on('connection', (ws) => {
  ws.on('message', (message) => {
    console.log('received: %s', message);
    ws.send(`Hello, you sent -> ${message}`);
  });
  ws.send('Welcome to the WebSocket server!');
});

server.listen(3000, () => {
  console.log('Server is listening on port 3000');
});
