const express = require('express');
const Player = require('../models/player');
const GameState = require('../models/game_state');

const router = express.Router();

router.post('/start', async (req, res) => {
  try {
    const { roomId } = req.body;
    const gameState = await GameState.create({ roomId, status: 'playing' });
    res.json(gameState);
  } catch (error) {
    res.status(500).json({ error: error.message });
  }
});

router.post('/move', async (req, res) => {
  try {
    const { playerId, steps } = req.body;
    const player = await Player.findByPk(playerId);
    if (!player) {
      return res.status(404).json({ error: 'Player not found' });
    }
    player.position = (player.position + steps) % 40;  // Assuming 40 spaces on the board
    await player.save();
    res.json(player);
  } catch (error) {
    res.status(500).json({ error: error.message });
  }
});

module.exports = router;
