const express = require('express');
const { Sequelize } = require('sequelize');
const Room = require('../models/room');
const Player = require('../models/player');

const router = express.Router();

router.post('/', async (req, res) => {
  try {
    const { name } = req.body;
    const code = Math.random().toString(36).substring(2, 6).toUpperCase();
    const room = await Room.create({ name, code, status: 'waiting' });
    res.json(room);
  } catch (error) {
    res.status(500).json({ error: error.message });
  }
});

router.post('/:code/join', async (req, res) => {
  try {
    const { code } = req.params;
    const { name } = req.body;
    const room = await Room.findOne({ where: { code } });
    if (!room) {
      return res.status(404).json({ error: 'Room not found' });
    }
    const player = await Player.create({ name, roomId: room.id, turnOrder: 0 });
    res.json(player);
  } catch (error) {
    res.status(500).json({ error: error.message });
  }
});

module.exports = router;
