import Vue from 'vue';
import Vuex from 'vuex';
import axios from 'axios';

Vue.use(Vuex);

export default new Vuex.Store({
  state: {
    rooms: [],
    players: [],
    gameState: null,
  },
  mutations: {
    SET_ROOMS(state, rooms) {
      state.rooms = rooms;
    },
    SET_PLAYERS(state, players) {
      state.players = players;
    },
    SET_GAME_STATE(state, gameState) {
      state.gameState = gameState;
    },
  },
  actions: {
    async fetchRooms({ commit }) {
      const response = await axios.get(`${process.env.VUE_APP_API_URL}/rooms`);
      commit('SET_ROOMS', response.data);
    },
    async fetchPlayers({ commit }, roomId) {
      const response = await axios.get(`${process.env.VUE_APP_API_URL}/players/${roomId}`);
      commit('SET_PLAYERS', response.data);
    },
    async startGame({ commit }, roomId) {
      const response = await axios.post(`${process.env.VUE_APP_API_URL}/game/start`, { roomId });
      commit('SET_GAME_STATE', response.data);
    },
  },
});
